@@ -17,6 +17,8 @@ sub entry {
     my $feed = $args->{feed}->clone;
     $feed->clear_entries;
     $feed->add_entry($args->{entry});
+    $feed->title($args->{entry}->title)
+        if $self->conf->{use_entry_title};
 
     push @{$self->{feeds}}, $feed;
 }
@@ -47,6 +49,16 @@ a bit hackish plugin but allows things like sending a single mail
 containing single entry, rather than a feed containing multiple
 entries, with Publish::Gmail plugin.
 
+=head1 CONFIG
+
+=over 4
+
+=item use_entry_title
+
+Use entry's title as a newly genrated feed title. Defaults to 0.
+
+=back
+
 =head1 AUTHOR
 
 Tatsuhiko Miyagawa
