@@ -3,16 +3,17 @@ use strict;
 use base qw( Template );
 
 use FindBin;
-use File::Spec;
+use File::Spec::Functions qw(catfile);
 
 use Template::Provider::Encoding 0.04;
 use Template::Stash::ForceUTF8;
 
 sub new {
-    my($class, $context) = @_;
+    my($class, $context, $plugin_class_id) = @_;
 
-    my $path = $context->conf->{template_path} || File::Spec->catfile($FindBin::Bin, "templates");
-    my $paths = [ $path, "$path/plugins" ];
+    my $path = $context->conf->{assets_path} || catfile($FindBin::Bin, "assets");
+    my $paths = [ catfile($path, "plugins", $plugin_class_id),
+                  catfile($path, "common") ];
 
     return $class->SUPER::new({
         INCLUDE_PATH => $paths,
@@ -20,6 +21,7 @@ sub new {
             Template::Provider::Encoding->new({ INCLUDE_PATH => $paths }),
         ],
         STASH => Template::Stash::ForceUTF8->new,
+        PLUGIN_BASE => [ 'Plagger::TT' ],
     });
 }
 
